summaryrefslogtreecommitdiffstats
path: root/style/qtc_kstyle.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2013-02-03 22:54:09 -0600
committerTimothy Pearson <[email protected]>2013-02-03 22:54:09 -0600
commitb063e7d3b4a86f46759db906ff2d907f33c96696 (patch)
tree2a9c1c3237cc2b7d2467c019048b118f66339266 /style/qtc_kstyle.h
parentf7ed00bca5c1789e9dfc80baa46ea6b3eb99f377 (diff)
downloadtde-style-qtcurve-b063e7d3b4a86f46759db906ff2d907f33c96696.tar.gz
tde-style-qtcurve-b063e7d3b4a86f46759db906ff2d907f33c96696.zip
Rename KStyle to TDEStyle to avoid conflicts with KDE4
Diffstat (limited to 'style/qtc_kstyle.h')
-rw-r--r--style/qtc_kstyle.h90
1 files changed, 45 insertions, 45 deletions
diff --git a/style/qtc_kstyle.h b/style/qtc_kstyle.h
index 63fa4fc..28fa024 100644
--- a/style/qtc_kstyle.h
+++ b/style/qtc_kstyle.h
@@ -1,7 +1,7 @@
/*
* $Id$
*
- * KStyle
+ * TDEStyle
* Copyright (C) 2001-2002 Karol Szwed <[email protected]>
*
* TQWindowsStyle CC_ListView and style images were kindly donated by TrollTech,
@@ -34,11 +34,11 @@
#include <tqcommonstyle.h>
-struct TQtCKStylePrivate;
+struct TQtCTDEStylePrivate;
/**
* Simplifies and extends the TQStyle API to make style coding easier.
*
* The KStyle class provides a simple internal menu transparency engine
* which attempts to use XRender for accelerated blending where requested,
* or falls back to fast internal software tinting/blending routines.
* It also simplifies more complex portions of the TQStyle API, such as
@@ -50,7 +50,7 @@ struct TQtCKStylePrivate;
* @author Karol Szwed ([email protected])
* @version $Id$
*/
-class TQtCKStyle: public TQCommonStyle
+class TQtCTDEStyle: public TQCommonStyle
{
Q_OBJECT
@@ -58,12 +58,12 @@ class TQtCKStyle: public TQCommonStyle
public:
/**
- * TQtCKStyle Flags:
+ * TQtCTDEStyle Flags:
*
* @li Default - Default style setting, where menu transparency
* and the FilledFrameWorkaround are disabled.
*
* @li AllowMenuTransparency - Enable this flag to use TQtCKStyle's
* internal menu transparency engine.
*
* @li FilledFrameWorkaround - Enable this flag to facilitate
@@ -73,15 +73,15 @@ class TQtCKStyle: public TQCommonStyle
* this workaround to enable painting of gradients in menubars and
* toolbars.
*/
- typedef uint KStyleFlags;
- enum KStyleOption {
+ typedef uint TDEStyleFlags;
+ enum TDEStyleOption {
Default = 0x00000000, //!< All options disabled
AllowMenuTransparency = 0x00000001, //!< Internal transparency enabled
FilledFrameWorkaround = 0x00000002 //!< Filled frames enabled
};
/**
- * KStyle ScrollBarType:
+ * TDEStyle ScrollBarType:
*
* Allows the style writer to easily select what type of scrollbar
* should be used without having to duplicate large amounts of source
@@ -101,9 +101,9 @@ class TQtCKStyle: public TQCommonStyle
* @li NextStyleScrollBar - Similar to the PlatinumStyle scroll bar, but
* with the buttons grouped on the opposite end of the scrollbar.
*
- * @see KStyle::KStyle()
+ * @see TDEStyle::TDEStyle()
*/
- enum KStyleScrollBarType {
+ enum TDEStyleScrollBarType {
WindowsStyleScrollBar = 0x00000000, //!< two button, windows style
PlatinumStyleScrollBar = 0x00000001, //!< two button, platinum style
ThreeButtonScrollBar = 0x00000002, //!< three buttons, %KDE style
@@ -111,31 +111,31 @@ class TQtCKStyle: public TQCommonStyle
};
/**
* Constructs a KStyle object.
*
* Select the appropriate KStyle flags and scrollbar type
* for your style. The user's style preferences selected in KControl
* are read by using TQSettings and are automatically applied to the style.
* As a fallback, KStyle paints progressbars and tabbars. It inherits from
* TQCommonStyle for speed, so don't expect much to be implemented.
*
* It is advisable to use a currently implemented style such as the HighColor
* style as a foundation for any new KStyle, so the limited number of
* drawing fallbacks should not prove problematic.
*
* @param flags the style to be applied
* @param sbtype the scroll bar type
- * @see KStyle::KStyleFlags
- * @see KStyle::KStyleScrollBarType
+ * @see TDEStyle::TDEStyleFlags
+ * @see TDEStyle::TDEStyleScrollBarType
* @author Karol Szwed ([email protected])
*/
- TQtCKStyle( KStyleFlags flags = TQtCKStyle::Default,
- KStyleScrollBarType sbtype = TQtCKStyle::WindowsStyleScrollBar );
+ TQtCTDEStyle( TDEStyleFlags flags = TQtCTDEStyle::Default,
+ TDEStyleScrollBarType sbtype = TQtCTDEStyle::WindowsStyleScrollBar );
/**
* Destructs the TQtCKStyle object.
*/
- ~TQtCKStyle();
+ ~TQtCTDEStyle();
/**
* Returns the default widget style depending on color depth.
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
* This function is only provided for convenience. It allows
* you to make a late decision about what scrollbar type to use for the
* style after performing some processing in your style's constructor.
* In most situations however, setting the scrollbar type via the TQtCKStyle
* constructor should suffice.
* @param sbtype the scroll bar type
- * @see TQtCKStyle::KStyleScrollBarType
+ * @see TQtCTDEStyle::TDEStyleScrollBarType
*/
- void setScrollBarType(KStyleScrollBarType sbtype);
+ void setScrollBarType(TDEStyleScrollBarType sbtype);
/**
* Returns the KStyle flags used to initialize the style.
*
* This is used solely for the kcmstyle module, and hence is internal.
*/
- KStyleFlags styleFlags() const;
+ TDEStyleFlags styleFlags() const;
/**
* KStyle Primitive Elements:
*
* The KStyle class extends the TQt's Style API by providing certain
* simplifications for parts of TQStyle. To do this, the KStylePrimitive
* elements were defined, which are very similar to TQt's PrimitiveElement.
*
* The first three Handle primitives simplify and extend PE_DockWindowHandle,
* so do not reimplement PE_DockWindowHandle if you want the KStyle handle
* simplifications to be operable. Similarly do not reimplement CC_Slider,
* SC_SliderGroove and SC_SliderHandle when using the KStyle slider
* primitives. KStyle automatically double-buffers slider painting
* when they are drawn via these KStyle primitives to avoid flicker.
*
* @li KPE_DockWindowHandle - This primitive is already implemented in KStyle,
* and paints a bevelled rect with the DockWindow caption text. Re-implement
* this primitive to perform other more fancy effects when drawing the dock window
* handle.
@@ -198,14 +198,14 @@ class TQtCKStyle: public TQCommonStyle
* paint the slider handle. The default implementation paints a filled rect of
* arbitrary color.
*
* @li KPE_ListViewExpander - This primitive is already implemented in KStyle. It
* is used to draw the Expand/Collapse element in TQListViews. To indicate the
* expanded state, the style flags are set to Style_Off, while Style_On implies collapsed.
*
* @li KPE_ListViewBranch - This primitive is already implemented in KStyle. It is
* used to draw the ListView branches where necessary.
*/
- enum KStylePrimitive {
+ enum TDEStylePrimitive {
KPE_DockWindowHandle,
KPE_ToolBarHandle,
KPE_GeneralHandle,
@@ -220,13 +220,13 @@ class TQtCKStyle: public TQCommonStyle
/**
* This function is identical to TQt's TQStyle::drawPrimitive(), except that
* it adds one further parameter, 'widget', that can be used to determine
* the widget state of the KStylePrimitive in question.
*
- * @see KStyle::KStylePrimitive
+ * @see TDEStyle::TDEStylePrimitive
* @see TQStyle::drawPrimitive
* @see TQStyle::drawComplexControl
*/
- virtual void drawKStylePrimitive( KStylePrimitive kpe,
+ virtual void drawTDEStylePrimitive( TDEStylePrimitive kpe,
TQPainter* p,
TQStyleControlElementData ceData,
ControlElementFlags elementFlags,
@@ -237,7 +237,7 @@ class TQtCKStyle: public TQCommonStyle
const TQWidget* widget = 0 ) const;
- enum KStylePixelMetric {
+ enum TDEStylePixelMetric {
KPM_MenuItemSeparatorHeight = 0x00000001,
KPM_MenuItemHMargin = 0x00000002,
KPM_MenuItemVMargin = 0x00000004,
@@ -249,7 +249,7 @@ class TQtCKStyle: public TQCommonStyle
KPM_ListViewBranchThickness = 0x00000100
};
- int kPixelMetric( KStylePixelMetric kpm, TQStyleControlElementData ceData, ControlElementFlags elementFlags, const TQWidget* widget = 0 ) const;
+ int kPixelMetric( TDEStylePixelMetric kpm, TQStyleControlElementData ceData, ControlElementFlags elementFlags, const TQWidget* widget = 0 ) const;
// ---------------------------------------------------------------------------
@@ -324,13 +324,13 @@ class TQtCKStyle: public TQCommonStyle
private:
// Disable copy constructor and = operator
- TQtCKStyle( const TQtCKStyle & );
- TQtCKStyle& operator=( const TQtCKStyle & );
+ TQtCTDEStyle( const TQtCTDEStyle & );
+ TQtCTDEStyle& operator=( const TQtCTDEStyle & );
protected:
virtual void virtual_hook( int id, void* data );
private:
- TQtCKStylePrivate *d;
+ TQtCTDEStylePrivate *d;
};
@@ -34,11 +34,11 @@
* Simplifies and extends the TQStyle API to make style coding easier.
*
- * The KStyle class provides a simple internal menu transparency engine
+ * The TDEStyle class provides a simple internal menu transparency engine
* which attempts to use XRender for accelerated blending where requested,
* or falls back to fast internal software tinting/blending routines.
@@ -58,12 +58,12 @@ class TQtCKStyle: public TQCommonStyle
* and the FilledFrameWorkaround are disabled.
*
- * @li AllowMenuTransparency - Enable this flag to use TQtCKStyle's
+ * @li AllowMenuTransparency - Enable this flag to use TQtCTDEStyle's
* internal menu transparency engine.
*
@@ -111,31 +111,31 @@ class TQtCKStyle: public TQCommonStyle
};
/**
- * Constructs a KStyle object.
+ * Constructs a TDEStyle object.
*
@@ -111,31 +111,31 @@ class TQtCKStyle: public TQCommonStyle
*
- * Select the appropriate KStyle flags and scrollbar type
+ * Select the appropriate TDEStyle flags and scrollbar type
* for your style. The user's style preferences selected in KControl
* are read by using TQSettings and are automatically applied to the style.
@@ -111,31 +111,31 @@ class TQtCKStyle: public TQCommonStyle
* for your style. The user's style preferences selected in KControl
* are read by using TQSettings and are automatically applied to the style.
- * As a fallback, KStyle paints progressbars and tabbars. It inherits from
+ * As a fallback, TDEStyle paints progressbars and tabbars. It inherits from
* TQCommonStyle for speed, so don't expect much to be implemented.
*
@@ -111,31 +111,31 @@ class TQtCKStyle: public TQCommonStyle
*
* It is advisable to use a currently implemented style such as the HighColor
- * style as a foundation for any new KStyle, so the limited number of
+ * style as a foundation for any new TDEStyle, so the limited number of
* drawing fallbacks should not prove problematic.
*
@@ -111,31 +111,31 @@ class TQtCKStyle: public TQCommonStyle
/**
- * Destructs the TQtCKStyle object.
+ * Destructs the TQtCTDEStyle object.
*/
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
* you to make a late decision about what scrollbar type to use for the
* style after performing some processing in your style's constructor.
- * In most situations however, setting the scrollbar type via the TQtCKStyle
+ * In most situations however, setting the scrollbar type via the TQtCTDEStyle
* constructor should suffice.
* @param sbtype the scroll bar type
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
/**
- * Returns the KStyle flags used to initialize the style.
+ * Returns the TDEStyle flags used to initialize the style.
*
* This is used solely for the kcmstyle module, and hence is internal.
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
/**
- * KStyle Primitive Elements:
+ * TDEStyle Primitive Elements:
*
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
*
- * The KStyle class extends the TQt's Style API by providing certain
- * simplifications for parts of TQStyle. To do this, the KStylePrimitive
+ * The TDEStyle class extends the TQt's Style API by providing certain
+ * simplifications for parts of TQStyle. To do this, the TDEStylePrimitive
* elements were defined, which are very similar to TQt's PrimitiveElement.
*
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
*
* The first three Handle primitives simplify and extend PE_DockWindowHandle,
- * so do not reimplement PE_DockWindowHandle if you want the KStyle handle
+ * so do not reimplement PE_DockWindowHandle if you want the TDEStyle handle
* simplifications to be operable. Similarly do not reimplement CC_Slider,
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
* simplifications to be operable. Similarly do not reimplement CC_Slider,
- * SC_SliderGroove and SC_SliderHandle when using the KStyle slider
- * primitives. KStyle automatically double-buffers slider painting
- * when they are drawn via these KStyle primitives to avoid flicker.
+ * SC_SliderGroove and SC_SliderHandle when using the TDEStyle slider
+ * primitives. TDEStyle automatically double-buffers slider painting
+ * when they are drawn via these TDEStyle primitives to avoid flicker.
*
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
*
- * @li KPE_DockWindowHandle - This primitive is already implemented in KStyle,
+ * @li KPE_DockWindowHandle - This primitive is already implemented in TDEStyle,
* and paints a bevelled rect with the DockWindow caption text. Re-implement
* this primitive to perform other more fancy effects when drawing the dock window
@@ -198,14 +198,14 @@ class TQtCKStyle: public TQCommonStyle
* arbitrary color.
*
- * @li KPE_ListViewExpander - This primitive is already implemented in KStyle. It
+ * @li KPE_ListViewExpander - This primitive is already implemented in TDEStyle. It
* is used to draw the Expand/Collapse element in TQListViews. To indicate the
* expanded state, the style flags are set to Style_Off, while Style_On implies collapsed.
@@ -198,14 +198,14 @@ class TQtCKStyle: public TQCommonStyle
* expanded state, the style flags are set to Style_Off, while Style_On implies collapsed.
*
- * @li KPE_ListViewBranch - This primitive is already implemented in KStyle. It is
+ * @li KPE_ListViewBranch - This primitive is already implemented in TDEStyle. It is
* used to draw the ListView branches where necessary.
*/
@@ -220,13 +220,13 @@ class TQtCKStyle: public TQCommonStyle
* This function is identical to TQt's TQStyle::drawPrimitive(), except that
* it adds one further parameter, 'widget', that can be used to determine
- * the widget state of the KStylePrimitive in question.
+ * the widget state of the TDEStylePrimitive in question.
*